# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulp_rpm.api_client import ApiClient
from pulpcore.client.pulp_rpm.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ContentModulemdDefaultsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, relative_path, module, stream, profiles, **kwargs):  # noqa: E501
        """Create a modulemd defaults  # noqa: E501

        Trigger an asynchronous task to create content,optionally create new repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(relative_path, module, stream, profiles, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relative_path: Path where the artifact is located relative to distributions base_path (required)
        :param str module: Modulemd name. (required)
        :param str stream: Modulemd default stream. (required)
        :param object profiles: Default profiles for modulemd streams. (required)
        :param str artifact: Artifact file representing the physical content
        :param file file: An uploaded file that may be turned into the artifact of the content unit.
        :param str repository: A URI of a repository the new content unit should be associated with.
        :param str upload: An uncommitted upload that may be turned into the artifact of the content unit.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_with_http_info(relative_path, module, stream, profiles, **kwargs)  # noqa: E501

    def create_with_http_info(self, relative_path, module, stream, profiles, **kwargs):  # noqa: E501
        """Create a modulemd defaults  # noqa: E501

        Trigger an asynchronous task to create content,optionally create new repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(relative_path, module, stream, profiles, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relative_path: Path where the artifact is located relative to distributions base_path (required)
        :param str module: Modulemd name. (required)
        :param str stream: Modulemd default stream. (required)
        :param object profiles: Default profiles for modulemd streams. (required)
        :param str artifact: Artifact file representing the physical content
        :param file file: An uploaded file that may be turned into the artifact of the content unit.
        :param str repository: A URI of a repository the new content unit should be associated with.
        :param str upload: An uncommitted upload that may be turned into the artifact of the content unit.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'relative_path',
            'module',
            'stream',
            'profiles',
            'artifact',
            'file',
            'repository',
            'upload'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'relative_path' is set
        if self.api_client.client_side_validation and ('relative_path' not in local_var_params or  # noqa: E501
                                                        local_var_params['relative_path'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relative_path` when calling `create`")  # noqa: E501
        # verify the required parameter 'module' is set
        if self.api_client.client_side_validation and ('module' not in local_var_params or  # noqa: E501
                                                        local_var_params['module'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `module` when calling `create`")  # noqa: E501
        # verify the required parameter 'stream' is set
        if self.api_client.client_side_validation and ('stream' not in local_var_params or  # noqa: E501
                                                        local_var_params['stream'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `stream` when calling `create`")  # noqa: E501
        # verify the required parameter 'profiles' is set
        if self.api_client.client_side_validation and ('profiles' not in local_var_params or  # noqa: E501
                                                        local_var_params['profiles'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `profiles` when calling `create`")  # noqa: E501

        if self.api_client.client_side_validation and ('relative_path' in local_var_params and  # noqa: E501
                                                        len(local_var_params['relative_path']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `relative_path` when calling `create`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('module' in local_var_params and  # noqa: E501
                                                        len(local_var_params['module']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `module` when calling `create`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('stream' in local_var_params and  # noqa: E501
                                                        len(local_var_params['stream']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `stream` when calling `create`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'artifact' in local_var_params:
            form_params.append(('artifact', local_var_params['artifact']))  # noqa: E501
        if 'relative_path' in local_var_params:
            form_params.append(('relative_path', local_var_params['relative_path']))  # noqa: E501
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501
        if 'repository' in local_var_params:
            form_params.append(('repository', local_var_params['repository']))  # noqa: E501
        if 'upload' in local_var_params:
            form_params.append(('upload', local_var_params['upload']))  # noqa: E501
        if 'module' in local_var_params:
            form_params.append(('module', local_var_params['module']))  # noqa: E501
        if 'stream' in local_var_params:
            form_params.append(('stream', local_var_params['stream']))  # noqa: E501
        if 'profiles' in local_var_params:
            form_params.append(('profiles', local_var_params['profiles']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/content/rpm/modulemd_defaults/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, **kwargs):  # noqa: E501
        """List modulemd defaultss  # noqa: E501

        ViewSet for Modulemd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Number of results to return per page.
        :param str module: Filter results where module matches value
        :param list[str] module__in: Filter results where module is in a comma-separated list of values
        :param int offset: The initial index from which to return the results.
        :param list[str] ordering: Ordering
        :param str repository_version: Repository Version referenced by HREF
        :param str repository_version_added: Repository Version referenced by HREF
        :param str repository_version_removed: Repository Version referenced by HREF
        :param str sha256:
        :param str stream: Filter results where stream matches value
        :param list[str] stream__in: Filter results where stream is in a comma-separated list of values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PaginatedrpmModulemdDefaultsResponseList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_with_http_info(**kwargs)  # noqa: E501

    def list_with_http_info(self, **kwargs):  # noqa: E501
        """List modulemd defaultss  # noqa: E501

        ViewSet for Modulemd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Number of results to return per page.
        :param str module: Filter results where module matches value
        :param list[str] module__in: Filter results where module is in a comma-separated list of values
        :param int offset: The initial index from which to return the results.
        :param list[str] ordering: Ordering
        :param str repository_version: Repository Version referenced by HREF
        :param str repository_version_added: Repository Version referenced by HREF
        :param str repository_version_removed: Repository Version referenced by HREF
        :param str sha256:
        :param str stream: Filter results where stream matches value
        :param list[str] stream__in: Filter results where stream is in a comma-separated list of values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PaginatedrpmModulemdDefaultsResponseList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'limit',
            'module',
            'module__in',
            'offset',
            'ordering',
            'repository_version',
            'repository_version_added',
            'repository_version_removed',
            'sha256',
            'stream',
            'stream__in',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'module' in local_var_params and local_var_params['module'] is not None:  # noqa: E501
            query_params.append(('module', local_var_params['module']))  # noqa: E501
        if 'module__in' in local_var_params and local_var_params['module__in'] is not None:  # noqa: E501
            query_params.append(('module__in', local_var_params['module__in']))  # noqa: E501
            collection_formats['module__in'] = 'csv'  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'ordering' in local_var_params and local_var_params['ordering'] is not None:  # noqa: E501
            query_params.append(('ordering', local_var_params['ordering']))  # noqa: E501
            collection_formats['ordering'] = 'csv'  # noqa: E501
        if 'repository_version' in local_var_params and local_var_params['repository_version'] is not None:  # noqa: E501
            query_params.append(('repository_version', local_var_params['repository_version']))  # noqa: E501
        if 'repository_version_added' in local_var_params and local_var_params['repository_version_added'] is not None:  # noqa: E501
            query_params.append(('repository_version_added', local_var_params['repository_version_added']))  # noqa: E501
        if 'repository_version_removed' in local_var_params and local_var_params['repository_version_removed'] is not None:  # noqa: E501
            query_params.append(('repository_version_removed', local_var_params['repository_version_removed']))  # noqa: E501
        if 'sha256' in local_var_params and local_var_params['sha256'] is not None:  # noqa: E501
            query_params.append(('sha256', local_var_params['sha256']))  # noqa: E501
        if 'stream' in local_var_params and local_var_params['stream'] is not None:  # noqa: E501
            query_params.append(('stream', local_var_params['stream']))  # noqa: E501
        if 'stream__in' in local_var_params and local_var_params['stream__in'] is not None:  # noqa: E501
            query_params.append(('stream__in', local_var_params['stream__in']))  # noqa: E501
            collection_formats['stream__in'] = 'csv'  # noqa: E501
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/content/rpm/modulemd_defaults/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaginatedrpmModulemdDefaultsResponseList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, rpm_modulemd_defaults_href, **kwargs):  # noqa: E501
        """Inspect a modulemd defaults  # noqa: E501

        ViewSet for Modulemd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(rpm_modulemd_defaults_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rpm_modulemd_defaults_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RpmModulemdDefaultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_with_http_info(rpm_modulemd_defaults_href, **kwargs)  # noqa: E501

    def read_with_http_info(self, rpm_modulemd_defaults_href, **kwargs):  # noqa: E501
        """Inspect a modulemd defaults  # noqa: E501

        ViewSet for Modulemd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(rpm_modulemd_defaults_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rpm_modulemd_defaults_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RpmModulemdDefaultsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'rpm_modulemd_defaults_href',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'rpm_modulemd_defaults_href' is set
        if self.api_client.client_side_validation and ('rpm_modulemd_defaults_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['rpm_modulemd_defaults_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rpm_modulemd_defaults_href` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'rpm_modulemd_defaults_href' in local_var_params:
            path_params['rpm_modulemd_defaults_href'] = local_var_params['rpm_modulemd_defaults_href']  # noqa: E501

        query_params = []
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{rpm_modulemd_defaults_href}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RpmModulemdDefaultsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmModulemdResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'md5': 'str',
        'sha1': 'str',
        'sha224': 'str',
        'sha256': 'str',
        'sha384': 'str',
        'sha512': 'str',
        'artifact': 'str',
        'name': 'str',
        'stream': 'str',
        'version': 'str',
        'static_context': 'bool',
        'context': 'str',
        'arch': 'str',
        'artifacts': 'object',
        'dependencies': 'object',
        'packages': 'list[str]'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'md5': 'md5',
        'sha1': 'sha1',
        'sha224': 'sha224',
        'sha256': 'sha256',
        'sha384': 'sha384',
        'sha512': 'sha512',
        'artifact': 'artifact',
        'name': 'name',
        'stream': 'stream',
        'version': 'version',
        'static_context': 'static_context',
        'context': 'context',
        'arch': 'arch',
        'artifacts': 'artifacts',
        'dependencies': 'dependencies',
        'packages': 'packages'
    }

    def __init__(self, pulp_href=None, pulp_created=None, md5=None, sha1=None, sha224=None, sha256=None, sha384=None, sha512=None, artifact=None, name=None, stream=None, version=None, static_context=None, context=None, arch=None, artifacts=None, dependencies=None, packages=None, local_vars_configuration=None):  # noqa: E501
        """RpmModulemdResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._md5 = None
        self._sha1 = None
        self._sha224 = None
        self._sha256 = None
        self._sha384 = None
        self._sha512 = None
        self._artifact = None
        self._name = None
        self._stream = None
        self._version = None
        self._static_context = None
        self._context = None
        self._arch = None
        self._artifacts = None
        self._dependencies = None
        self._packages = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if md5 is not None:
            self.md5 = md5
        if sha1 is not None:
            self.sha1 = sha1
        if sha224 is not None:
            self.sha224 = sha224
        if sha256 is not None:
            self.sha256 = sha256
        if sha384 is not None:
            self.sha384 = sha384
        if sha512 is not None:
            self.sha512 = sha512
        if artifact is not None:
            self.artifact = artifact
        self.name = name
        self.stream = stream
        self.version = version
        if static_context is not None:
            self.static_context = static_context
        self.context = context
        self.arch = arch
        self.artifacts = artifacts
        self.dependencies = dependencies
        if packages is not None:
            self.packages = packages

    @property
    def pulp_href(self):
        """Gets the pulp_href of this RpmModulemdResponse.  # noqa: E501


        :return: The pulp_href of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this RpmModulemdResponse.


        :param pulp_href: The pulp_href of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this RpmModulemdResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this RpmModulemdResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this RpmModulemdResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this RpmModulemdResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def md5(self):
        """Gets the md5 of this RpmModulemdResponse.  # noqa: E501

        The MD5 checksum if available.  # noqa: E501

        :return: The md5 of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this RpmModulemdResponse.

        The MD5 checksum if available.  # noqa: E501

        :param md5: The md5 of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._md5 = md5

    @property
    def sha1(self):
        """Gets the sha1 of this RpmModulemdResponse.  # noqa: E501

        The SHA-1 checksum if available.  # noqa: E501

        :return: The sha1 of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this RpmModulemdResponse.

        The SHA-1 checksum if available.  # noqa: E501

        :param sha1: The sha1 of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._sha1 = sha1

    @property
    def sha224(self):
        """Gets the sha224 of this RpmModulemdResponse.  # noqa: E501

        The SHA-224 checksum if available.  # noqa: E501

        :return: The sha224 of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha224

    @sha224.setter
    def sha224(self, sha224):
        """Sets the sha224 of this RpmModulemdResponse.

        The SHA-224 checksum if available.  # noqa: E501

        :param sha224: The sha224 of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._sha224 = sha224

    @property
    def sha256(self):
        """Gets the sha256 of this RpmModulemdResponse.  # noqa: E501

        The SHA-256 checksum if available.  # noqa: E501

        :return: The sha256 of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this RpmModulemdResponse.

        The SHA-256 checksum if available.  # noqa: E501

        :param sha256: The sha256 of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._sha256 = sha256

    @property
    def sha384(self):
        """Gets the sha384 of this RpmModulemdResponse.  # noqa: E501

        The SHA-384 checksum if available.  # noqa: E501

        :return: The sha384 of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha384

    @sha384.setter
    def sha384(self, sha384):
        """Sets the sha384 of this RpmModulemdResponse.

        The SHA-384 checksum if available.  # noqa: E501

        :param sha384: The sha384 of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._sha384 = sha384

    @property
    def sha512(self):
        """Gets the sha512 of this RpmModulemdResponse.  # noqa: E501

        The SHA-512 checksum if available.  # noqa: E501

        :return: The sha512 of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha512

    @sha512.setter
    def sha512(self, sha512):
        """Sets the sha512 of this RpmModulemdResponse.

        The SHA-512 checksum if available.  # noqa: E501

        :param sha512: The sha512 of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._sha512 = sha512

    @property
    def artifact(self):
        """Gets the artifact of this RpmModulemdResponse.  # noqa: E501

        Artifact file representing the physical content  # noqa: E501

        :return: The artifact of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this RpmModulemdResponse.

        Artifact file representing the physical content  # noqa: E501

        :param artifact: The artifact of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """

        self._artifact = artifact

    @property
    def name(self):
        """Gets the name of this RpmModulemdResponse.  # noqa: E501

        Modulemd name.  # noqa: E501

        :return: The name of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RpmModulemdResponse.

        Modulemd name.  # noqa: E501

        :param name: The name of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def stream(self):
        """Gets the stream of this RpmModulemdResponse.  # noqa: E501

        Stream name.  # noqa: E501

        :return: The stream of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._stream

    @stream.setter
    def stream(self, stream):
        """Sets the stream of this RpmModulemdResponse.

        Stream name.  # noqa: E501

        :param stream: The stream of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and stream is None:  # noqa: E501
            raise ValueError("Invalid value for `stream`, must not be `None`")  # noqa: E501

        self._stream = stream

    @property
    def version(self):
        """Gets the version of this RpmModulemdResponse.  # noqa: E501

        Modulemd version.  # noqa: E501

        :return: The version of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this RpmModulemdResponse.

        Modulemd version.  # noqa: E501

        :param version: The version of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def static_context(self):
        """Gets the static_context of this RpmModulemdResponse.  # noqa: E501

        Modulemd static-context flag.  # noqa: E501

        :return: The static_context of this RpmModulemdResponse.  # noqa: E501
        :rtype: bool
        """
        return self._static_context

    @static_context.setter
    def static_context(self, static_context):
        """Sets the static_context of this RpmModulemdResponse.

        Modulemd static-context flag.  # noqa: E501

        :param static_context: The static_context of this RpmModulemdResponse.  # noqa: E501
        :type: bool
        """

        self._static_context = static_context

    @property
    def context(self):
        """Gets the context of this RpmModulemdResponse.  # noqa: E501

        Modulemd context.  # noqa: E501

        :return: The context of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this RpmModulemdResponse.

        Modulemd context.  # noqa: E501

        :param context: The context of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and context is None:  # noqa: E501
            raise ValueError("Invalid value for `context`, must not be `None`")  # noqa: E501

        self._context = context

    @property
    def arch(self):
        """Gets the arch of this RpmModulemdResponse.  # noqa: E501

        Modulemd architecture.  # noqa: E501

        :return: The arch of this RpmModulemdResponse.  # noqa: E501
        :rtype: str
        """
        return self._arch

    @arch.setter
    def arch(self, arch):
        """Sets the arch of this RpmModulemdResponse.

        Modulemd architecture.  # noqa: E501

        :param arch: The arch of this RpmModulemdResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and arch is None:  # noqa: E501
            raise ValueError("Invalid value for `arch`, must not be `None`")  # noqa: E501

        self._arch = arch

    @property
    def artifacts(self):
        """Gets the artifacts of this RpmModulemdResponse.  # noqa: E501

        Modulemd artifacts.  # noqa: E501

        :return: The artifacts of this RpmModulemdResponse.  # noqa: E501
        :rtype: object
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this RpmModulemdResponse.

        Modulemd artifacts.  # noqa: E501

        :param artifacts: The artifacts of this RpmModulemdResponse.  # noqa: E501
        :type: object
        """

        self._artifacts = artifacts

    @property
    def dependencies(self):
        """Gets the dependencies of this RpmModulemdResponse.  # noqa: E501

        Modulemd dependencies.  # noqa: E501

        :return: The dependencies of this RpmModulemdResponse.  # noqa: E501
        :rtype: object
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this RpmModulemdResponse.

        Modulemd dependencies.  # noqa: E501

        :param dependencies: The dependencies of this RpmModulemdResponse.  # noqa: E501
        :type: object
        """

        self._dependencies = dependencies

    @property
    def packages(self):
        """Gets the packages of this RpmModulemdResponse.  # noqa: E501

        Modulemd artifacts' packages.  # noqa: E501

        :return: The packages of this RpmModulemdResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._packages

    @packages.setter
    def packages(self, packages):
        """Sets the packages of this RpmModulemdResponse.

        Modulemd artifacts' packages.  # noqa: E501

        :param packages: The packages of this RpmModulemdResponse.  # noqa: E501
        :type: list[str]
        """

        self._packages = packages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmModulemdResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmModulemdResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "3.17.10"

# import apis into sdk package
from pulpcore.client.pulp_rpm.api.acs_rpm_api import AcsRpmApi
from pulpcore.client.pulp_rpm.api.content_advisories_api import ContentAdvisoriesApi
from pulpcore.client.pulp_rpm.api.content_distribution_trees_api import ContentDistributionTreesApi
from pulpcore.client.pulp_rpm.api.content_modulemd_defaults_api import ContentModulemdDefaultsApi
from pulpcore.client.pulp_rpm.api.content_modulemds_api import ContentModulemdsApi
from pulpcore.client.pulp_rpm.api.content_packagecategories_api import ContentPackagecategoriesApi
from pulpcore.client.pulp_rpm.api.content_packageenvironments_api import ContentPackageenvironmentsApi
from pulpcore.client.pulp_rpm.api.content_packagegroups_api import ContentPackagegroupsApi
from pulpcore.client.pulp_rpm.api.content_packagelangpacks_api import ContentPackagelangpacksApi
from pulpcore.client.pulp_rpm.api.content_packages_api import ContentPackagesApi
from pulpcore.client.pulp_rpm.api.content_repo_metadata_files_api import ContentRepoMetadataFilesApi
from pulpcore.client.pulp_rpm.api.distributions_rpm_api import DistributionsRpmApi
from pulpcore.client.pulp_rpm.api.publications_rpm_api import PublicationsRpmApi
from pulpcore.client.pulp_rpm.api.remotes_rpm_api import RemotesRpmApi
from pulpcore.client.pulp_rpm.api.remotes_uln_api import RemotesUlnApi
from pulpcore.client.pulp_rpm.api.repositories_rpm_api import RepositoriesRpmApi
from pulpcore.client.pulp_rpm.api.repositories_rpm_versions_api import RepositoriesRpmVersionsApi
from pulpcore.client.pulp_rpm.api.rpm_comps_api import RpmCompsApi
from pulpcore.client.pulp_rpm.api.rpm_copy_api import RpmCopyApi

# import ApiClient
from pulpcore.client.pulp_rpm.api_client import ApiClient
from pulpcore.client.pulp_rpm.configuration import Configuration
from pulpcore.client.pulp_rpm.exceptions import OpenApiException
from pulpcore.client.pulp_rpm.exceptions import ApiTypeError
from pulpcore.client.pulp_rpm.exceptions import ApiValueError
from pulpcore.client.pulp_rpm.exceptions import ApiKeyError
from pulpcore.client.pulp_rpm.exceptions import ApiException
# import models into sdk package
from pulpcore.client.pulp_rpm.models.addon_response import AddonResponse
from pulpcore.client.pulp_rpm.models.artifact_response import ArtifactResponse
from pulpcore.client.pulp_rpm.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_rpm.models.checksum_response import ChecksumResponse
from pulpcore.client.pulp_rpm.models.comps_xml import CompsXml
from pulpcore.client.pulp_rpm.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_rpm.models.copy import Copy
from pulpcore.client.pulp_rpm.models.image_response import ImageResponse
from pulpcore.client.pulp_rpm.models.metadata_checksum_type_enum import MetadataChecksumTypeEnum
from pulpcore.client.pulp_rpm.models.package_checksum_type_enum import PackageChecksumTypeEnum
from pulpcore.client.pulp_rpm.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_distribution_tree_response_list import PaginatedrpmDistributionTreeResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_modulemd_defaults_response_list import PaginatedrpmModulemdDefaultsResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_modulemd_response_list import PaginatedrpmModulemdResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_category_response_list import PaginatedrpmPackageCategoryResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_environment_response_list import PaginatedrpmPackageEnvironmentResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_group_response_list import PaginatedrpmPackageGroupResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_langpacks_response_list import PaginatedrpmPackageLangpacksResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_response_list import PaginatedrpmPackageResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_repo_metadata_file_response_list import PaginatedrpmRepoMetadataFileResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_alternate_content_source_response_list import PaginatedrpmRpmAlternateContentSourceResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_distribution_response_list import PaginatedrpmRpmDistributionResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_publication_response_list import PaginatedrpmRpmPublicationResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_remote_response_list import PaginatedrpmRpmRemoteResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_repository_response_list import PaginatedrpmRpmRepositoryResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_uln_remote_response_list import PaginatedrpmUlnRemoteResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_update_record_response_list import PaginatedrpmUpdateRecordResponseList
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_alternate_content_source import PatchedrpmRpmAlternateContentSource
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_distribution import PatchedrpmRpmDistribution
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_remote import PatchedrpmRpmRemote
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_repository import PatchedrpmRpmRepository
from pulpcore.client.pulp_rpm.models.patchedrpm_uln_remote import PatchedrpmUlnRemote
from pulpcore.client.pulp_rpm.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_rpm.models.repair import Repair
from pulpcore.client.pulp_rpm.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_rpm.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_rpm.models.rpm_distribution_tree_response import RpmDistributionTreeResponse
from pulpcore.client.pulp_rpm.models.rpm_modulemd import RpmModulemd
from pulpcore.client.pulp_rpm.models.rpm_modulemd_defaults import RpmModulemdDefaults
from pulpcore.client.pulp_rpm.models.rpm_modulemd_defaults_response import RpmModulemdDefaultsResponse
from pulpcore.client.pulp_rpm.models.rpm_modulemd_response import RpmModulemdResponse
from pulpcore.client.pulp_rpm.models.rpm_package import RpmPackage
from pulpcore.client.pulp_rpm.models.rpm_package_category_response import RpmPackageCategoryResponse
from pulpcore.client.pulp_rpm.models.rpm_package_environment_response import RpmPackageEnvironmentResponse
from pulpcore.client.pulp_rpm.models.rpm_package_group_response import RpmPackageGroupResponse
from pulpcore.client.pulp_rpm.models.rpm_package_langpacks_response import RpmPackageLangpacksResponse
from pulpcore.client.pulp_rpm.models.rpm_package_response import RpmPackageResponse
from pulpcore.client.pulp_rpm.models.rpm_repo_metadata_file_response import RpmRepoMetadataFileResponse
from pulpcore.client.pulp_rpm.models.rpm_repository_sync_url import RpmRepositorySyncURL
from pulpcore.client.pulp_rpm.models.rpm_rpm_alternate_content_source import RpmRpmAlternateContentSource
from pulpcore.client.pulp_rpm.models.rpm_rpm_alternate_content_source_response import RpmRpmAlternateContentSourceResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_distribution import RpmRpmDistribution
from pulpcore.client.pulp_rpm.models.rpm_rpm_distribution_response import RpmRpmDistributionResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_publication import RpmRpmPublication
from pulpcore.client.pulp_rpm.models.rpm_rpm_publication_response import RpmRpmPublicationResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_remote import RpmRpmRemote
from pulpcore.client.pulp_rpm.models.rpm_rpm_remote_response import RpmRpmRemoteResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_repository import RpmRpmRepository
from pulpcore.client.pulp_rpm.models.rpm_rpm_repository_response import RpmRpmRepositoryResponse
from pulpcore.client.pulp_rpm.models.rpm_uln_remote import RpmUlnRemote
from pulpcore.client.pulp_rpm.models.rpm_uln_remote_response import RpmUlnRemoteResponse
from pulpcore.client.pulp_rpm.models.rpm_update_collection import RpmUpdateCollection
from pulpcore.client.pulp_rpm.models.rpm_update_collection_response import RpmUpdateCollectionResponse
from pulpcore.client.pulp_rpm.models.rpm_update_record import RpmUpdateRecord
from pulpcore.client.pulp_rpm.models.rpm_update_record_response import RpmUpdateRecordResponse
from pulpcore.client.pulp_rpm.models.skip_types_enum import SkipTypesEnum
from pulpcore.client.pulp_rpm.models.sync_policy_enum import SyncPolicyEnum
from pulpcore.client.pulp_rpm.models.task_group_operation_response import TaskGroupOperationResponse
from pulpcore.client.pulp_rpm.models.variant_response import VariantResponse

